@@ -41,14 +41,13 @@
 #'   or on a GUI frontend (headless = FALSE).
 #' @return No return value, called for publishing a message.
 #' @examples
-#' \dontrun{
 #' feedback(
 #'   print_this = "Error occured when counting source_data",
 #'   type = "Error",
 #'   findme = "255bb3695c",
-#'   logfile_dir = rv$logfile_dir,
-#'   headless = rv$headless
-#' )}
+#'   logfile_dir = tempdir(),
+#'   headless = TRUE
+#' )
 #'
 #' @export
 #'
@@ -69,7 +68,7 @@ feedback <-
 
     # If the gui is active, show the message to the user.
     # If its an error message, also show the error messages in the gui
-    # even if the user did not explicitely said it should be displayed
+    # even if the user did not explicitly said it should be displayed
     # in the gui
     if (isTRUE(ui) ||
         (isFALSE(headless) &&
@@ -272,6 +271,7 @@ feedback_to_logfile <-
     # and a linebreak at the end:
     res <- paste0("[", Sys.time(), "] ", res, "\n")
 
+    logfile_dir <- repair_dir(logfile_dir)
     path_with_file <- paste0(logfile_dir, "logfile.log")
 
     # Open the connection to the logfile:
@@ -282,6 +282,13 @@ feedback_to_logfile <-
     close(log_con)
   }
 
+repair_dir <- function(dir) {
+  if (!grepl("\\/$", dir)) {
+    dir <- paste0(dir, "/")
+  }
+  return(dir)
+}
+
 #' @title Format the feedback string
 #' @description  Helper function for the feedback function to combine the input
 #'   parameters in proper manner to ge a pretty and informative string which
@@ -318,13 +325,12 @@ feedback_get_formatted_string <-
 #' @inheritParams feedback
 #' @return No return value, called for side effects (see description)
 #' @examples
-#' \dontrun{
 #' cleanup_old_logfile("path/to/logfile/dir/")
-#' }
 #'
 #' @export
 #'
 cleanup_old_logfile <- function(logfile_dir) {
+  logfile_dir <- repair_dir(logfile_dir)
   path_with_file <- paste0(logfile_dir, "logfile.log")
   # Check if logfile.log is already the logfile for this session:
   if (isTRUE(file.exists(path_with_file))) {
